@@ -1,6 +1,8 @@
 from prodigy.gameData import gameData
 from prodigy.gameStatus import gameStatus
-from prodigy.getAsset import get_asset
+from prodigy.get_asset import get_asset
+from prodigy.get_friend_requests import get_friend_requests
+from prodigy.get_userID import get_userID
 from prodigy.player import player, update_player
 from prodigy.prodigy import Prodigy
 from prodigy.tokenify import tokenify
@@ -9,6 +11,8 @@ __all__ = [
     "gameData",
     "gameStatus",
     "get_asset",
+    "get_friend_requests",
+    "get_userID",
     "player",
     "update_player",
     "Prodigy",
